@@ -2,7 +2,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.23_01';
+$VERSION = '0.23_02';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -179,7 +179,6 @@ sub cc_append_to_inc{
     for my $dir(@dirs){
         unless(-d $dir){
             warn("'$dir' not found: $!\n");
-            exit;
         }
 
         _verbose "inc: -I$dir" if _VERBOSE;
@@ -197,19 +196,10 @@ sub cc_append_to_inc{
     return;
 }
 
-
 sub cc_libs {
-    goto &cc_append_to_libs;
-}
+    my ($self, @libs) = @_;
 
-sub cc_append_to_libs{
-    my($self, @libs) = @_;
-
-    $self->_xs_initialize();
-
-    my $mm = $self->makemaker_args;
-
-    my $libs = join q{ }, map{
+    @libs = map{
         my($name, $dir) = ref($_) eq 'ARRAY' ? @{$_} : ($_, undef);
         my $lib;
         if(defined $dir) {
@@ -218,12 +208,26 @@ sub cc_append_to_libs{
         else {
             $lib = '';
         }
-        $lib .= ($name =~ /^-/ ? qq{$name } : qq{-l$name});
+        $lib .= ($name =~ /^-/ ? qq{$name} : qq{-l$name});
         _verbose "libs: $lib" if _VERBOSE;
         $lib;
     } @libs;
 
-    if($mm->{LIBS}){
+    $self->cc_append_to_libs( @libs );
+}
+
+sub cc_append_to_libs{
+    my($self, @libs) = @_;
+
+    $self->_xs_initialize();
+
+    return unless @libs;
+
+    my $libs = join q{ }, @libs;
+
+    my $mm = $self->makemaker_args;
+
+    if ($mm->{LIBS}){
         $mm->{LIBS} .= q{ } . $libs;
     }
     else{
@@ -232,6 +236,32 @@ sub cc_append_to_libs{
     return $libs;
 }
 
+sub cc_assert_lib {
+    my ($self, @dcl_args) = @_;
+
+    if ( ! $self->{xsu_loaded_checklib} ) {
+        my $loaded_lib = 0;
+        foreach my $checklib qw(inc::Devel::CheckLib Devel::CheckLib) {
+            eval "use $checklib 0.4";
+            if (!$@) {
+                $loaded_lib = 1;
+                last;
+            }
+        }
+
+        if (! $loaded_lib) {
+            warn "Devel::CheckLib not found in inc/ nor \@INC";
+            exit 0;
+        }
+
+        $self->{xsu_loaded_checklib}++;
+        $self->configure_requires( "Devel::CheckLib" => "0.4" );
+        $self->build_requires( "Devel::CheckLib" => "0.4" );
+    }
+
+    Devel::CheckLib::check_lib_or_exit(@dcl_args);
+}
+
 sub cc_append_to_ccflags{
     my($self, @ccflags) = @_;
 
@@ -559,7 +589,7 @@ Module::Install::XSUtil - Utility functions for XS modules
 
 =head1 VERSION
 
-This document describes Module::Install::XSUtil version 0.23_01.
+This document describes Module::Install::XSUtil version 0.23_02.
 
 =head1 SYNOPSIS
 
@@ -658,6 +688,12 @@ e.g.:
     cc_libs  'foo'; # ditto.
     cc_libs qw(-L/path/to/libs foo bar); # with library paths
 
+=head2 cc_assert_lib %args
+
+Checks if the given C library is installed via Devel::CheckLib. 
+Takes exactly what Devel::CheckLib takes. Note that you must pass
+the path names explicitly.
+
 =head2 install_headers ?@header_files
 
 Declares providing header files, extracts functions from these header files,
